[hide private]
[frames] | no frames]

[ Identifiers | To Do ]

# To Do List

To Do in pype32.datatypes.Array.__init__ Before to add an element to the array we must check if the type of that element is one we are expecting.

To Do in pype32.datatypes.String.__init__ Add a UnicodeString class.

To Do in pype32.directories.NetMetaDataTables.__init__ Parse every table in this struct and store them in the `self.tables` attribute.

To Do in pype32.pype32.PE.__init__ Parse the Resource directory. Parse the Delay Imports directory. Parse the Exception directory. Add dump() method to show nicely all the structure of the PE file.